@@ -58,7 +58,7 @@ extern void pdf_bayes_factor_header(world_fmt *world, option_fmt *options);
 extern void pdf_bayes_factor_rawscores_header(world_fmt *world, option_fmt *options);
 extern void pdf_bayes_factor_rawscores(long locus, MYREAL rawtermo, MYREAL beziertermo, MYREAL harmo);
 void pdf_bayes_factor_rawscores_harmo(long locus, MYREAL harmo);
-extern void pdf_bayes_factor(world_fmt *world, MYREAL tsum, MYREAL tsum2, MYREAL hsum, MYREAL asum, long maxreplicate);
+extern void pdf_bayes_factor(world_fmt *world, MYREAL tsum, MYREAL tsum2, MYREAL hsum, MYREAL asum, long maxreplicate, MYREAL scaling_factor);
 extern void pdf_burnin_stops(world_fmt *world, long maxreplicate);
 // MIGHIST output
 //extern void 
@@ -85,6 +85,11 @@ extern long prepare_profile_table(char method, long which, MYREAL *likes, MYREAL
 extern void pdf_print_profile_percentile (world_fmt * world);
 
 extern void pdf_histogram_legend(void);
+extern void pdf_print_lrt_header(MYREAL aicfull, long aicfullparamnum,  float *page_width,  float *page_height);
+extern void pdf_print_LRT_box(world_fmt* world,char **box,long size,
+			      MYREAL like0, MYREAL like1,MYREAL lrt, MYREAL chiprob, MYREAL chiprob2, MYREAL aic, long df, 
+			      long aicparamnum, float *page_height, float *page_width);
+
 
 // write PDF content to file
 extern int pdf_write_file(option_fmt *options);
