@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: random.c 1553 2009-06-09 15:29:10Z beerli $
+$Id: random.c 1701 2010-06-13 21:00:45Z beerli $
 -------------------------------------------------------*/
 /* \file random.c */
 #include "sighandler.h"
@@ -45,6 +45,12 @@ $Id: random.c 1553 2009-06-09 15:29:10Z beerli $
 #include <dmalloc.h>
 #endif
 
+
+#ifdef SNOWLEOPARD
+#include <dispatch/dispatch.h>
+#endif
+
+
 #ifdef PTHREADS
 extern tpool_t heating_pool;
 #endif
@@ -639,9 +645,19 @@ randum (void)
     fprintf(stdout,"%i> R:%f\n",myID,val);
     return val;
 #else
-    MYREAL r = genrand_res53();
-    //fprintf(stdout,"%f\n",r);
+#ifdef SNOWLEOPARD
+    //    MYREAL r;
+    // dispatch_queue_t queue = dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_DEFAULT, 0);
+    //dispatch_async(queue,
+    //		   ^{     
+		     MYREAL r = genrand_res53();
+		     //		   } 
+		     //);
     return r;
+#else
+    MYREAL r = genrand_res53();
+    return r;
+#endif
 #endif
 #else
 MYREAL value;
