@@ -22,7 +22,7 @@
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-   $Id: sighandler.c 675 2007-04-15 02:16:53Z beerli $                  
+   $Id: sighandler.c 1549 2009-06-04 20:06:57Z beerli $                  
    ----------------------------------------------------- */
 /*! \file sighandler.c */
 #include "sighandler.h"
@@ -281,7 +281,7 @@ usererror (char string[], ...)
 void
 sig_error (char string[], char filename[], long line)
 {
-    fprintf (stdout, "\nERROR in file %s on line %li\nERROR %s\n", filename, line, string);
+  fprintf (stdout, "\n%i> ERROR in file %s on line %li\nERROR %s\n", myID, filename, line, string);
     exit (EXIT_FAILURE);
 }
 
@@ -296,26 +296,31 @@ sig_error (char string[], char filename[], long line)
 char 
 myfgets (char *buffer, long bufsize, FILE * infile)
 {
-    long count = 0;
-    char ch = '\0';
-    bufsize--;
-    while (!(ch == '\r' || ch == '\n' || ch == EOF) && count < bufsize)
+  long count = 0;
+  char ch = '\0';
+  char oldch;
+  bufsize--;
+  ch = fgetc (infile);
+  while (!(ch == '\r' || ch == '\n' || ch == EOF) && count < bufsize)
     {
-        ch = fgetc (infile);
-        buffer[count] = ch;
-        count++;
+      //ch = fgetc (infile);
+      buffer[count] = ch;
+      count++;
+      ch = fgetc (infile);
     }
-    //buffer[count]=ch;
-    if (ch == '\r')
+  if (ch == '\r')
     {
-        ch = fgetc (infile);
-        if (ch != '\n')
-            ungetc (ch, infile);
+      oldch = ch;
+      ch = fgetc (infile);
+      if(!((ch == EOF) || (ch == '\n')))
+	{
+	  ungetc (ch, infile);
+	  buffer[count] = '\0';
+	   return oldch;
+	}
     }
-    buffer[count - 1] = '\0';
-    //debug
-    //printf("MYFGETS> %s\n",buffer);
-    return ch;
+  buffer[count] = '\0';
+  return ch;
 }
 
 #ifdef NEXTAPP
